## Installation

password generator requires [Python](https://python.org/) py3 to run..

```sh
pip install password_generator_ifanps
```

## How to use

```sh
import generator

print(generator.password_generator(level_password))
```